Riak Python Client
=====================

Installation
------------

#. Ensure Riak installed & running. (``riak ping``)
#. Install the Python client:

  #. If you use Pip_, ``pip install riak``.
  #. If you use easy_install_, run ``easy_install riak``.
  #. You can download the package off PyPI_, extract it and run
     ``python setup.py install``.

.. _Pip: http://pip.openplans.org/
.. _easy_install: http://pypi.python.org/pypi/setuptools
.. _PyPI: http://pypi.python.org/pypi/riak/1.4.0

Contents:

.. toctree::
   :maxdepth: 2

   tutorial

   client
   bucket
   riak_object
   mapreduce

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

